==> hudi-0.12.3.src.tgz: hudi-0.12.3/hudi-spark-datasource/hudi-spark-common/src/main/java/org/apache/hudi/internal/BaseWriterCommitMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.internal;

import org.apache.hudi.client.HoodieInternalWriteStatus;

import java.util.Arrays;
import java.util.List;

/**
 * Base class for HoodieWriterCommitMessage used by Spark datasource v2.
 */
public class BaseWriterCommitMessage {

  private List<HoodieInternalWriteStatus> writeStatuses;

  public BaseWriterCommitMessage(List<HoodieInternalWriteStatus> writeStatuses) {
    this.writeStatuses = writeStatuses;
  }

  public List<HoodieInternalWriteStatus> getWriteStatuses() {
    return writeStatuses;
  }

  @Override
  public String toString() {
    return "HoodieWriterCommitMessage{" + "writeStatuses=" + Arrays.toString(writeStatuses.toArray()) + '}';
  }
}

==> hudi-1.0.1.src.tgz: hudi-1.0.1/hudi-spark-datasource/hudi-spark-common/src/main/java/org/apache/hudi/internal/BaseWriterCommitMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.internal;

import org.apache.hudi.client.WriteStatus;

import java.io.Serializable;
import java.util.Arrays;
import java.util.List;

/**
 * Base class for HoodieWriterCommitMessage used by Spark datasource v2.
 */
public class BaseWriterCommitMessage implements Serializable {

  private List<WriteStatus> writeStatuses;

  public BaseWriterCommitMessage(List<WriteStatus> writeStatuses) {
    this.writeStatuses = writeStatuses;
  }

  public List<WriteStatus> getWriteStatuses() {
    return writeStatuses;
  }

  @Override
  public String toString() {
    return "HoodieWriterCommitMessage{" + "writeStatuses=" + Arrays.toString(writeStatuses.toArray()) + '}';
  }
}
